import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/types'
import { Zone } from '@prisma/client'
import ZoneRepository from '../../../repositories/zoneRepository'
import CharacterManager from '../../../managers/characterManager'
import characterRepository from '../../../repositories/characterRepository'
import logger from '../../../utilities/logger'

interface IPayload {}

/**
 * Handle game master list zones event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:zone_editor:zone:list', async (data: IPayload, callback: (response: Zone[]) => void) => {
    const character = await characterRepository.getById(socket.characterId as number);
    if (!character) return
    
    if (character.role !== 'gm') {
      logger.info(`User ${character.id} tried to list zones but is not a game master.`)
      return
    }

    logger.info(`User ${character.id} has requested zone list via zone editor.`)

    try {
      const zones = await ZoneRepository.getAll()
      callback(zones)
    } catch (e) {
      console.error(e)
      callback([])
    }
  })
}
