import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/types'
import ZoneRepository from '../../../repositories/zoneRepository'
import { Character, Zone } from '@prisma/client'
import CharacterManager from '../../../managers/characterManager'
import characterRepository from '../../../repositories/characterRepository'
import logger from '../../../utilities/logger'

interface IPayload {
  zoneId: number
}

/**
 * Handle game master zone request event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:zone_editor:zone:request', async (data: IPayload, callback: (response: Zone) => void) => {
    const character = await characterRepository.getById(socket.characterId as number);
    if (!character) return

    if (character.role !== 'gm') {
      logger.info(`User ${character!.id} tried to request zone but is not a game master.`)
      return
    }

    logger.info(`User ${character.id} has requested zone via zone editor.`)

    if (!data.zoneId) {
      logger.info(`User ${character.id} tried to request zone but did not provide a zone id.`)
      return
    }

    try {
      const zone = await ZoneRepository.getById(data.zoneId)

      if (!zone) {
        logger.info(`User ${character.id} tried to request zone ${data.zoneId} but it does not exist.`)
        return
      }

      callback(zone)
    } catch (e) {
      console.error(e)
    }
  })
}
